@@ -3,7 +3,7 @@ extern void MakeSearchPopup();
 /* These are for the TOP section of the search window, aka searchnumbers[] */
 enum {G_LABEL,G_INPUT,F_LABEL,F_INPUT,POUND_LABEL,POUND_INPUT,
 	H_LABEL,H_INPUT,N_LABEL,N_INPUT,U_LABEL,U_INPUT,
-	INUSEFILE, SHOWUSEFILE,
+	INUSEFILE, SHOWUSEFILE, RADLIST_L, RADLIST_D,
 	NUM_OF_N };
 
 /* These are for the normal user input stuff, aka searchwidgets[] */
@@ -12,9 +12,11 @@ enum {
 	SEARCH_ENG_L, SEARCH_ENG_W,
 	SEARCH_KANJI_L, SEARCH_SKIP_W,
 	SEARCH_STROKE_W,
-	SEARCH_KANJI_L2, SEARCH_KANJIPASTE,
+	SEARCH_RADICAL_W,
+	SEARCH_KANJIPASTE,
 	KANA_FORM,
-	SEARCH_KANA_L, SEARCH_KANA_W, SEARCH_STARTTOG, SEARCH_VTOG,
+	SEARCH_KANA_L,SEARCH_KANA_B, SEARCH_KANA_W,
+	SEARCH_ACTIVEFILTER, SEARCH_STARTTOG, 
 	NUM_OF_W};
 
 
@@ -23,6 +25,7 @@ extern Widget searchnumbers[NUM_OF_N];
 
 extern void MakeSearchPopup();
 extern void printsearch(TRANSLATION);
+extern void UpdateSearchlabels();
 extern void SearchCallback(Widget,XtPointer,XtPointer);
 
 
@@ -53,6 +56,8 @@ extern XChar2b kanastring[MAXKANALENGTH];
 
 /* For searches, insist on match from start of word */
 extern int match_onlyatstart;
+/* For searches, on use "active" (ie: 'would show in guess output') */
+extern int match_onlyactive;
 
 /* no point in making this more than once, so share it */
 extern Cursor textcursor;
